@@ -7,7 +7,7 @@
 name = 'Eric-Tools'
 __title__ = 'tools'
 __description__ = 'Python HTTP for Humans.'
-__version__ = "1.1.3.1"
+__version__ = "1.1.3.2"
 __author__ = 'Eric'
 __doc__ = ["Python Daily Development Tools"]
 __url__ = "https://github.com/Eric-jxl/Tools"
@@ -15,8 +15,10 @@ __license__ = "MIT"
 
 from . import exception_class
 from . import resize_image
-from . import logger,ip
+from . import logger
+import ip
 from . import encryption_classmethod
 from . import pgsql
 from . import sftp
 import readconfig
+import send_email
